# ResourceConfig

This object provides a container for all common configuration related to a Resource. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**roles_config** | [**RolesConfig**](RolesConfig.md) |  | [optional] 
**rules_config** | [**RulesConfig**](RulesConfig.md) |  | [optional] 
**display_info** | [**DisplayInfo**](DisplayInfo.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


